@@ -41,12 +41,13 @@ class Maneuver:
         self.impulses = args
         # HACK: Change API or validation code
         _dts, _dvs = zip(*args)
-        self._dts, self._dvs = self._initialize(
-            [(_dt * u.one).value for _dt in _dts] * (_dts[0] * u.one).unit,
-            [(_dv * u.one).value for _dv in _dvs] * (_dvs[0] * u.one).unit,
-        )
+
         try:
-            if not all(len(dv) == 3 for dv in self._dvs):
+            self._dts, self._dvs = self._initialize(
+                [(_dt * u.one).value for _dt in _dts] * (_dts[0] * u.one).unit,
+                [(_dv * u.one).value for _dv in _dvs] * (_dvs[0] * u.one).unit,
+            )
+            if not all(len(dv) == 3 for dv in _dvs):
                 raise TypeError
         except TypeError:
             raise ValueError("Delta-V must be three dimensions vectors")
@@ -97,10 +98,10 @@ class Maneuver:
         k = orbit_i.attractor.k
 
         rv = orbit_i.rv()
-        rv = (rv[0].to(u.m).value, rv[-1].to(u.m / u.s).value)
+        rv = (rv[0].to_value(u.m), rv[-1].to_value(u.m / u.s))
 
-        k = k.to(u.m ** 3 / u.s ** 2).value
-        r_f = r_f.to(u.m).value
+        k = k.to_value(u.m ** 3 / u.s ** 2)
+        r_f = r_f.to_value(u.m)
 
         dv_a, dv_b, t_trans = hohmann_fast(k, rv, r_f)
         dv_a, dv_b, t_trans = dv_a * u.m / u.s, dv_b * u.m / u.s, t_trans * u.s
@@ -135,11 +136,11 @@ class Maneuver:
         k = orbit_i.attractor.k
 
         rv = orbit_i.rv()
-        rv = (rv[0].to(u.m).value, rv[-1].to(u.m / u.s).value)
+        rv = (rv[0].to_value(u.m), rv[-1].to_value(u.m / u.s))
 
-        k = k.to(u.m ** 3 / u.s ** 2).value
-        r_b = r_b.to(u.m).value
-        r_f = r_f.to(u.m).value
+        k = k.to_value(u.m ** 3 / u.s ** 2)
+        r_b = r_b.to_value(u.m)
+        r_f = r_f.to_value(u.m)
 
         dv_a, dv_b, dv_c, t_trans1, t_trans2 = bielliptic_fast(
             k,
@@ -189,10 +190,7 @@ class Maneuver:
         sols = list(method(k, r_i, r_f, tof, **kwargs))
 
         # Return short or long solution
-        if short:
-            dv_a, dv_b = sols[0]
-        else:
-            dv_a, dv_b = sols[-1]
+        dv_a, dv_b = sols[0] if short else sols[-1]
 
         return cls(
             (0 * u.s, (dv_a - orbit_i.v).decompose()),
@@ -245,8 +243,8 @@ class Maneuver:
                 f"The correction maneuver is not yet supported with {orbit.ecc},it should be less than or equal to 0.001"
             )
 
-        R = orbit.attractor.R.to(u.km).value
-        k = orbit.attractor.k.to(u.km ** 3 / u.s ** 2).value
+        R = orbit.attractor.R.to_value(u.km)
+        k = orbit.attractor.k.to_value(u.km ** 3 / u.s ** 2)
         v = orbit.v.value
         a = orbit.a.value
         inc = orbit.inc.value
